'use client'

import React, { useEffect, useRef } from 'react'
import { motion, useAnimation } from 'framer-motion'
import { useInView } from 'react-intersection-observer'

interface InfoBoxProps {
  title: string
  content: string
  number: string
  gradientClass: string
}

const infoBoxes: InfoBoxProps[] = [
  {
    title: "Title 1",
    content: "Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry's standard dummy text ever since the 1500s.",
    number: "01",
    gradientClass: "ibs-gradient-1"
  },
  {
    title: "Title 2",
    content: "When an unknown printer took a galley of type and scrambled it to make a type specimen book. It has survived not only five centuries.",
    number: "02",
    gradientClass: "ibs-gradient-2"
  },
  {
    title: "Title 3",
    content: "But also the leap into electronic typesetting, remaining essentially unchanged. It was popularised in the 1960s.",
    number: "03",
    gradientClass: "ibs-gradient-3"
  },
  {
    title: "Title 4",
    content: "With the release of Letraset sheets containing Lorem Ipsum passages, and more recently with desktop publishing software.",
    number: "04",
    gradientClass: "ibs-gradient-4"
  }
]

const InfoBox: React.FC<InfoBoxProps> = ({ title, content, number, gradientClass }) => {
  const controls = useAnimation()
  const [ref, inView] = useInView({
    triggerOnce: true,
    threshold: 0.1,
  })

  useEffect(() => {
    if (inView) {
      controls.start('visible')
    }
  }, [controls, inView])

  return (
    <motion.div
      ref={ref}
      className={`ibs-info-box bg-gray-800 rounded-lg p-6 relative overflow-hidden ${gradientClass}`}
      initial="hidden"
      animate={controls}
      variants={{
        hidden: { opacity: 0, y: 50 },
        visible: { opacity: 1, y: 0, transition: { duration: 0.5 } }
      }}
      whileHover={{ scale: 1.05 }}
    >
      <h3 className="ibs-title text-xl font-bold text-white mb-2 relative z-10">{title}</h3>
      <p className="ibs-content text-gray-400 text-sm relative z-10">{content}</p>
      <span className="ibs-number absolute top-0 right-0 text-9xl font-bold text-gray-700 opacity-20 -mt-6 -mr-4">
        {number}
      </span>
    </motion.div>
  )
}

const InfoBoxSection: React.FC = () => {
  return (
    <section className="ibs-section bg-gray-900 py-16 px-4">
      <div className="ibs-container max-w-6xl mx-auto">
        <div className="ibs-grid grid grid-cols-1 md:grid-cols-2 lg:grid-cols-4 gap-6">
          {infoBoxes.map((box, index) => (
            <InfoBox key={index} {...box} />
          ))}
        </div>
      </div>
    </section>
  )
}

export default InfoBoxSection